@@ -14,7 +14,7 @@
 #' enframe(1:3)
 #' enframe(c(a = 5, b = 7))
 enframe <- function(x, name = "name", value = "value") {
-  if (is.null(names(x))) {
+  if (is_null(names(x))) {
     df <- tibble(seq_along(x), x)
   } else {
     df <- tibble(names(x), unname(x))
