@@ -44,13 +44,15 @@
 #' tibble(y = strptime("2000/01/01", "%x"))
 #' }
 tibble <- function(...) {
-  as_tibble(lst(...))
+  xs <- quos(..., .named = TRUE)
+  as_tibble(lst_quos(xs, expand = TRUE))
 }
 
 #' @export
 #' @rdname tibble
 tibble_ <- function(xs) {
-  as_tibble(lst_(xs))
+  xs <- compat_lazy_dots(xs, caller_env())
+  tibble(!!! xs)
 }
 
 #' @export
@@ -116,7 +118,7 @@ recycle_columns <- function(x) {
 
   # Validate column lengths
   lengths <- map_int(x, NROW)
-  max <- max(lengths)
+  max <- max(c(lengths[lengths != 1L], 0L))
 
   bad_len <- lengths != 1L & lengths != max
   if (any(bad_len)) {
@@ -126,7 +128,7 @@ recycle_columns <- function(x) {
   }
 
   short <- lengths == 1
-  if (max != 1L && any(short)) {
+  if (max > 1L && any(short)) {
     x[short] <- map(x[short], rep, max)
   }
 
