@@ -86,6 +86,16 @@ test_that("can add row inbetween", {
   expect_identical(df_new, tibble(a = c(1:2, 4:5, 3L)))
 })
 
+test_that("can safely add to factor columns everywhere (#296)", {
+  df <- tibble(a = factor(letters[1:3]))
+  expect_identical(add_row(df), tibble(a = factor(c(letters[1:3], NA))))
+  expect_identical(add_row(df, .before = 1), tibble(a = factor(c(NA, letters[1:3]))))
+  expect_identical(add_row(df, .before = 2), tibble(a = factor(c("a", NA, letters[2:3]))))
+  expect_identical(add_row(df, a = "d"), tibble(a = factor(c(letters[1:4]))))
+  expect_identical(add_row(df, a = "d", .before = 1), tibble(a = factor(c("d", letters[1:3]))))
+  expect_identical(add_row(df, a = "d", .before = 2), tibble(a = factor(c("a", "d", letters[2:3]))))
+})
+
 test_that("error if both .before and .after are given", {
   df <- tibble(a = 1:3)
   expect_error(
@@ -200,6 +210,12 @@ test_that("can recyle when adding multiple columns of length 1", {
   expect_identical(df_new, tibble(a = 1:3, b = rep(4, 3), c = rep(5, 3)))
 })
 
+test_that("can recyle for zero-row data frame (#167)", {
+  df <- tibble(a = 1:3)[0, ]
+  df_new <- add_column(df, b = 4, c = character())
+  expect_identical(df_new, tibble(a = integer(), b = numeric(), c = character()))
+})
+
 test_that("can add as first column via .before = 1", {
   df <- tibble(a = 3L)
   df_new <- add_column(df, b = 2L, .before = 1)
